function simMat = ali2mat(fileName)
%ali2mat - convert ali format to Matlab matrix
%
% USAGE  simMat = ali2mat(fileName)
% Converts a similarity matrix from ali format to matlab matrix.
% CAUTION: simMat will be symmetric, independently of the original matrix
% symmetry.

%% Figure out the matrix dimensions and symmetry from header lines
fid = fopen(fileName, 'r');
dimLine = fgetl(fid);
dimVec = str2num(dimLine); %#ok
symFlag = fgetl(fid);
fclose(fid);

%% Read in similarity data
simMat = textread(fileName, '', 'headerlines',2);

% Matlab indexes arrays from 1, but ali format indexes arrays from 0:
simMat(:,1:2) = simMat(:,1:2) + 1;

% If symmetric, must compose full matrix:
% append switched row and column indexes (transposed), but take out the 
% diagonal elements because matlab sums duplicate entries when composing
% sparse matrices.
if strcmp(symFlag, 'symmetric')
  % Find diagonal elements
  diagIdx = find(simMat(:, 1) == simMat(:,2));
  appendData = simMat;
  appendData(diagIdx,:) = [];
  %switch rows and cols
  appendData = [appendData(:,2) appendData(:,1) appendData(:,3)]; 
  simMat = [simMat; appendData];
  clear appendData;
  simMat = sparse(simMat(:,1), simMat(:,2), simMat(:,3), dimVec(1), dimVec(2));

  % Quick sanity check for simmetry
  mustBeAllZeros = simMat - simMat.';
  if( sum(sum(mustBeAllZeros)) ~= 0 )
    error('File says "symmetric", but matrix is not symmetric');
  end
  
else 
  % CAREFUL: not symmetric to begin with so we force symmetric similarity
  simMat = sparse(simMat(:,1), simMat(:,2), simMat(:,3), dimVec(1), dimVec(2));
  simMat = (simMat + simMat') / 2; % <-- CAREFUL 
end % if strcmp

return

  
