function write_partition(partition, filename)
%write_partition - write a Similarity-based Learning Repository partition file.
% Write a partition file in the format of the Similarity-based Learning
% Repository.
% USAGE
% writePartitionFile(partitionStruct, filename)
% partitionStruct: a structure with fields
%   testNum: number of test splits
%   cvNum: number of cross-validation folds per test split
%   testIdx: cell array containg the indices of each split's test samples
%   cvIdx: cell array containing the indices of each cross-validation's
%   test samples.
% 

% Written by Yihua Chen, Ph.D. Student Dept EE, Univ. Washington
% Help written by Luca Cazzanti, engineer.
% Applied Physics Laboratory, University of Washington, March 2009.
%$Id:$
%$DateTime:$
%$Author:$

fid = fopen(filename, 'w');

fprintf(fid, '%d %d\n', partition.testNum, partition.cvNum);

for i = 1:partition.testNum
	write_vector(partition.testIdx{i}, fid);
	for j = 1:partition.cvNum
		write_vector(partition.cvIdx{i, j}, fid);
	end
end

fclose(fid);

function write_vector(vec, fid)

n = length(vec);

for i = 1:(n-1)
	fprintf(fid, '%d ', vec(i) - 1);
end

fprintf(fid, '%d\n', vec(n) - 1);
