function [classEst, posteriors modelParams] = classifyLocalBda( ...
  testFeatureVec, neighborFeatureMat, neighborClassLabels)
%classifyLocalBda - classify with the local BDA classifier.
% Classify a test feature vector using the local Bayesian discriminant
% Analysis classifier. This function consists of a call to
% computeBdaModels() and a call to classifyBda().
% USAGE:
% [classEst, posteriors, modelParams] = classifyLocalBda( ...
%     testFeatureVec, neighborFeatureMat, neighborClassLabels);
% testFeatureVec: 1-by-F feature vector to be classified.
% neighborFeatureMat: M-by-F matrix of feature vectors, each row
%     corresponding to a neighbor of the test sample.
% neighborClassLabels: M-by-1 vector of class labels for the neighbors.
% classEst: the class estimate.
% posteriors: class posterior probabilities.
% modelParams: the local BDA model parameters as returned by computeBdaModels().
%
% See also computeBdaModels, classifyBda.

% Written by Luca Cazzanti, enginner.
% Applied Physics Lab - University of Washington, Feb 2009.
% Originally written by Santosh Srivastava and Sergey Feldman,
% University of Washington, Dept. Electrical Engineering.


% Compute BDA model from neighbors
modelParams = computeBdaModels(neighborFeatureMat, neighborClassLabels);

% Running the bda algorithm
[classEst, posteriors] = classifyBda(testFeatureVec, modelParams);

return


