function modelParams = initCentroidModels()
%initCentroidModels - create empty structure for centroid models.
% Creates a trivial structure with empty fields suitable for storing the
% model parameters for a nearest centroid classifier and ancillary
% information.
%
% USAGE
% modelParams = initCentroidModels;
% modelParams: structure with emtpy fields, except boolean field
% isTrivial = true. For details on the contents of the fields after
% the centroid models are computed, see computeCentroidModels(). The fields
% are:
%   isTrivial: boolean flag (true).
%   classPriors: vector of class prior probabilities. 
%   classCounts: vector of class frequency counts for the training set.
%   classLabels: vector of class labels.
%   centroidIdx: vector of indeces into the columns of the training pairwise
%       similarity matrix, indicating the class centroids in the training set.
%   centroidType: a string denoting the type of centroid used for the models.
%
% See also computeCentroidModels, classifyNearestCentroid, findCentroid.

% Written by Luca Cazzanti, engineer
% Applied Physics Laboratory, University of Washington, Jan 2007.
%$Id:$
%$DateTime:$
%$Author:$

modelParams.isTrivial = true;
modelParams.classPriors = [];
modelParams.classCounts = [];
modelParams.classLabels = [];
modelParams.centroidIdx = [];
modelParams.centroidType = [];

return