function initCentroidIdx = initMultiCentroids(nCentroidsPerClass, classLabels)
%initMultiCentroids - initialize multiple centroids per class.
% Provides initial centroids to be used with findMultipleCentroids(). For
% now, only random initialization is implemented.
%
% USAGE
% initCentroidIdx = initMultiCentroids(nCentroidsPerClass, classLabels)
% nCentroidsPerClass: a scalar or a vector indicating the number of
%   centroids to be generated for each class. If a vector, its length must
%   be equal to the number of unique class labels in classLabels.
% classLabels: vector of class labels corresponding to each sample in a
%   training set.
% initCentroidIdx: indices into classLabels denoting the selected
%   centroids. The actual training samples are not needed by this function,
%   but their corresponding class labels are.

% Written by Luca Cazzanti, engineer
% Applied Physics Laboratory, University of Washington, Feb 2007.
%$Id:$
%$DateTime:$
%$Author:$

% For now just random initialization - later, we can add sexier
% initialization strategies
initCentroidIdx = [];
uniqueClassLabels = unique(classLabels);
nClasses = length(uniqueClassLabels);

if isscalar(nCentroidsPerClass)
  nCentroidsPerClass = nCentroidsPerClass * ones(nClasses, 1);
elseif length(nCentroidsPerClass) ~= nClasses
  error('Inconsistent number of classes');
end

for iClass = 1:nClasses
  thisNumCentroids = nCentroidsPerClass(iClass);
  thisClassLabel = uniqueClassLabels(iClass);
  thisClassIdx = find(classLabels == thisClassLabel);
  randOrder = randperm(length(thisClassIdx));
  randIdx = thisClassIdx(randOrder);
  randIdx = randIdx(:).'; %make sure it's a row vector
  initCentroidIdx = [initCentroidIdx randIdx(1:thisNumCentroids)];
end
initCentroidIdx = sort(initCentroidIdx);

return