function modelParams = initSdaModels()
%initSdaModels - creates an empty structure for the SDA model parameters.
% Creates a trivial structure with empty fields suitable for storing the
% model parameters for an SDA classifier and ancillary information.
%
% USAGE
% modelParams = initSdaModels;
% modelParams: structure with empty fields, except boolean field
% isTrivial = true. For details on the contents of the fields after the SDA
% models are computed, see computeSdaModels(). The fields
% are:
%   isTrivial: boolean flag (true).
%   classPriors: vector of class prior probabilities. 
%   classCounts: vector of class frequency counts for the training set.
%   classLabels: vector of class labels.
%   centroidIdx: vector of indeces into the columns of the training
%     pairwise similarity matrix, indicating the class centroids in the
%     training set.
%   centroidType: a string denoting the type of centroid used for the
%     models.
%   gamma: matrix of gamma parameters.
%   lambda: matrix of lambda parameters.
%   meanSim: matrix of mean similarities.
%   estErr: matrix of estimation errors.
%   simDomain: vector of similarity domain values.
%
% See also computeSdaModels, classifySda, computeMaxEntModels.

% Written by Luca Cazzanti, engineer
% Applied Physics Laboratory, University of Washington, Jan 2007.
%$Id:$
%$DateTime:$
%$Author:$

modelParams.isTrivial = true;
modelParams.classPriors = [];
modelParams.classCounts = [];
modelParams.classLabels = [];
modelParams.centroidIdx = [];
modelParams.centroidType = [];
modelParams.gamma = [];
modelParams.lambda = [];
modelParams.meanSim = [];
modelParams.estErr = [];
modelParams.simDomain = [];

return